@@ -45,94 +45,86 @@ Locals
  * of other bricks are initiated as these are send by network */
 void client_brick_remove( int mx, int my, int type, Vector imp, Paddle *paddle )
 {
-	int px, py, w, h, i, j, shadow, anim_brick_id;
-	int expl_brick = 0; /* explosive bricks have their explosion as animation */
-	int dir;
+  int px, py, w, h, i, j, shadow, anim_brick_id;
+  int dir;
 
-	/* if explosive set exp_time of surrounding bricks */
-	if ( game->bricks[mx][my].type == MAP_BRICK_EXP ) {
-		/* add explosion animation */
-		exp_create( mx * BRICK_WIDTH + ( BRICK_WIDTH >> 1 ), 
-			    my * BRICK_HEIGHT + ( BRICK_HEIGHT >> 1 ) );
-		type = SHR_BY_EXPL; /* if expl brick was it by NORMAL_BALL it is
-				       handled as EXPL anyway */
+  /* add explosion animation */
+  if ( type == SHR_BY_EXPL_WITH_EXPL ) {
+    exp_create( mx * BRICK_WIDTH + ( BRICK_WIDTH >> 1 ), 
+		my * BRICK_HEIGHT + ( BRICK_HEIGHT >> 1 ) );
 #ifdef AUDIO_ENABLED
-		stk_sound_play_x( mx * BRICK_WIDTH + ( BRICK_WIDTH >> 1 ), wav_boom );
+    stk_sound_play_x( mx * BRICK_WIDTH + ( BRICK_WIDTH >> 1 ), wav_boom );
 #endif
-	}
+    type = SHR_BY_EXPL; /* WITH_EXPL is not known */
+  }
     
-	/* decrease brick count if no indestructible brick was destroyed */
-	if ( game->bricks[mx][my].dur != -1 )
-		game->bricks_left--;
+  /* decrease brick count if no indestructible brick was destroyed */
+  if ( game->bricks[mx][my].dur != -1 )
+    game->bricks_left--;
 
-    /* before removing the brick, store the brick id for animation */
-    anim_brick_id = game->bricks[mx][my].id;
+  /* before removing the brick, store the brick id for animation */
+  anim_brick_id = game->bricks[mx][my].id;
     
-	/* remove brick from map */
-	game->bricks[mx][my].brick_c = ' ';
-	game->bricks[mx][my].id = -1;
-	game->bricks[mx][my].dur = -1;
-	game->bricks[mx][my].exp_time = -1;
-	game->bricks[mx][my].heal_time = -1;
-	game->bricks[mx][my].type = MAP_EMPTY;
+  /* remove brick from map */
+  game->bricks[mx][my].brick_c = ' ';
+  game->bricks[mx][my].id = -1;
+  game->bricks[mx][my].dur = -1;
+  game->bricks[mx][my].exp_time = -1;
+  game->bricks[mx][my].heal_time = -1;
+  game->bricks[mx][my].type = MAP_EMPTY;
     
-	/* get screen position */
-	px = mx * BRICK_WIDTH;
-	py = my * BRICK_HEIGHT;
+  /* get screen position */
+  px = mx * BRICK_WIDTH;
+  py = my * BRICK_HEIGHT;
     
-	/* release extra if one exists. in opposite to the server the goldshower
-	 * 1000P is not released here but in the hit handle function if the gold_shower
-	 * flag is set to avoid releasing 'ghost' extras due to latency. */
-	dir = ( paddle->type == PADDLE_TOP ) ? -1 : 1;
-	if ( game->bricks[mx][my].extra != EX_NONE ) {
-		if ( game->diff->allow_maluses || 
-		     !extra_is_malus( game->bricks[mx][my].extra ) )
-			list_add( game->extras, 
-			   	  extra_create( game->bricks[mx][my].extra, px, py, dir ) );
-	}
-	game->bricks[mx][my].extra = EX_NONE;
-	game->bricks[mx][my].extra_c = ' ';
+  /* release extra if one exists. in opposite to the server the goldshower
+   * 1000P is not released here but in the hit handle function if the gold_shower
+   * flag is set to avoid releasing 'ghost' extras due to latency. */
+  dir = ( paddle->type == PADDLE_TOP ) ? -1 : 1;
+  if ( game->bricks[mx][my].extra != EX_NONE ) {
+    if ( game->diff->allow_maluses || 
+	 !extra_is_malus( game->bricks[mx][my].extra ) )
+      list_add( game->extras, 
+		extra_create( game->bricks[mx][my].extra, px, py, dir ) );
+  }
+  game->bricks[mx][my].extra = EX_NONE;
+  game->bricks[mx][my].extra_c = ' ';
 
-	/* in case of darkness no (graphical) remove nescessary */
-	if ( game->extra_active[EX_DARKNESS] ) {
+  /* in case of darkness no (graphical) remove nescessary */
+  if ( game->extra_active[EX_DARKNESS] ) {
 #ifdef AUDIO_ENABLED
-		stk_sound_play_x( px, wav_boom );
+    stk_sound_play_x( px, wav_boom );
 #endif
-		return;
-	}		
+    return;
+  }		
 
-	/* add shrapnells */
-	if ( !expl_brick )
-    {
-		/*shrapnells_create( offscreen, px, py, BRICK_WIDTH, BRICK_HEIGHT, type, imp );*/
-        shrapnells_create( brick_pic, anim_brick_id * BRICK_WIDTH, 0, 
-                           BRICK_WIDTH, BRICK_HEIGHT,
-                           px, py, type, imp );
+  shrapnells_create( brick_pic, anim_brick_id * BRICK_WIDTH, 0, 
+		     BRICK_WIDTH, BRICK_HEIGHT,
+		     px, py, type, imp );
+  /* recreate shine if needed */
+  if (px == shine_x && py == shine_y) shine_recreate = 1;
+  /* clear offscreen */
+  w = BRICK_WIDTH + shadow_size; h = BRICK_HEIGHT + shadow_size;
+  if ( px + w > stk_display->w - BRICK_WIDTH ) 
+    w = stk_display->w - BRICK_WIDTH - px;
+  stk_surface_clip( offscreen, px, py, w, h );
+  stk_surface_blit( bkgnd, px, py, w, h, offscreen, px, py );
+  /* if shadow redraw close bricks */
+  for ( i = mx - 1; i <= mx + 1; i++ )
+    for ( j = my - 1; j <= my + 1; j++ ) {
+      if ( i > 0 && j > 0 && i < MAP_WIDTH - 1 ) {
+	if ( game->bricks[i][j].type != MAP_EMPTY ) {
+	  if ( i <= mx && j <= my ) shadow = 1; else shadow = 0;
+	  brick_draw( offscreen, i, j, shadow );
+	}
+      }
     }
-	/* recreate shine if needed */
-	if (px == shine_x && py == shine_y) shine_recreate = 1;
-	/* clear offscreen */
-	w = BRICK_WIDTH + shadow_size; h = BRICK_HEIGHT + shadow_size;
-	if ( px + w > stk_display->w - BRICK_WIDTH ) 
-		w = stk_display->w - BRICK_WIDTH - px;
-	stk_surface_clip( offscreen, px, py, w, h );
-	stk_surface_blit( bkgnd, px, py, w, h, offscreen, px, py );
-	/* if shadow redraw close bricks */
-	for ( i = mx - 1; i <= mx + 1; i++ )
-		for ( j = my - 1; j <= my + 1; j++ ) {
-			if ( i > 0 && j > 0 && i < MAP_WIDTH - 1 ) {
-				if ( game->bricks[i][j].type != MAP_EMPTY ) {
-					if ( i <= mx && j <= my ) shadow = 1; else shadow = 0;
-					brick_draw( offscreen, i, j, shadow );
-				}
-			}
-		}
-	stk_surface_clip( offscreen, 0, 0, 0, 0 );
-	/* update screen */
-	stk_surface_blit( offscreen, px, py, w, h, stk_display, px, py );
-	stk_display_store_drect();
+  stk_surface_clip( offscreen, 0, 0, 0, 0 );
+  /* update screen */
+  stk_surface_blit( offscreen, px, py, w, h, stk_display, px, py );
+  stk_display_store_drect();
 #ifdef AUDIO_ENABLED
-	stk_sound_play_x( px, wav_boom );
+  stk_sound_play_x( px, wav_boom );
 #endif
 }
 
@@ -295,31 +287,34 @@ void client_brick_loose_dur( int mx, int my, int points )
 /* handle a received brick action */
 void client_handle_brick_hit( BrickHit *hit )
 {
-	Paddle *paddle;
-	Vector imp;
+  Paddle *paddle;
+  Vector imp;
 	
-	paddle = (hit->paddle==PADDLE_BOTTOM)?game->paddles[PADDLE_BOTTOM]:game->paddles[PADDLE_TOP];
-	angle2vec( hit->degrees, &imp );
+  paddle = (hit->paddle==PADDLE_BOTTOM)?game->paddles[PADDLE_BOTTOM]:game->paddles[PADDLE_TOP];
+  angle2vec( hit->degrees, &imp );
 	
-	switch ( hit->type ) {
-		case HT_HIT:
-			client_brick_loose_dur( hit->x, hit->y, 1 );
-			break;
-		case HT_REMOVE:
-			client_brick_remove( hit->x, hit->y, hit->dest_type, imp, paddle );
-			/* gold shower extra */
-			if ( hit->gold_shower )
-				list_add( game->extras,
-					extra_create( EX_SCORE1000, 
-						hit->x*BRICK_WIDTH, hit->y*BRICK_HEIGHT, 
-						(hit->paddle==PADDLE_TOP)?-1:1 ) );
-			break;
-		case HT_HEAL:
-			client_brick_heal( hit->x, hit->y );
-			break;
-		case HT_GROW:
-			client_brick_grow( hit->x, hit->y );
-			break;
-	}
+  switch ( hit->type )
+    {
+    case HT_HIT:
+      client_brick_loose_dur( hit->x, hit->y, 1 );
+      break;
+    case HT_REMOVE:
+      if (hit->draw_explosion)
+	hit->dest_type = SHR_BY_EXPL_WITH_EXPL;
+      client_brick_remove( hit->x, hit->y, hit->dest_type, imp, paddle );
+      /* gold shower extra */
+      if ( hit->gold_shower )
+	list_add( game->extras,
+		  extra_create( EX_SCORE1000, 
+				hit->x*BRICK_WIDTH, hit->y*BRICK_HEIGHT, 
+				(hit->paddle==PADDLE_TOP)?-1:1 ) );
+      break;
+    case HT_HEAL:
+      client_brick_heal( hit->x, hit->y );
+      break;
+    case HT_GROW:
+      client_brick_grow( hit->x, hit->y );
+      break;
+    }
 }
 
