@@ -18,7 +18,6 @@
 #include "lbreakout.h"
 #include "config.h"
 #include "event.h"
-#include "levels.h"
 #include "../gui/gui.h"
 #include "client_data.h"
 #include "client_handlers.h"
@@ -36,15 +35,21 @@ extern StkFont *chat_font_error;
 extern StkFont *chat_font_name;
 extern StkFont *chat_font_normal;
 extern char chatter[CHAT_LINE_COUNT][CHAT_LINE_WIDTH];
+extern char pause_chatter[CHAT_LINE_COUNT][CHAT_LINE_WIDTH];
 extern List *client_levelsets;
 extern List *client_users;
 extern List *client_games;
 extern List *client_channels;
-extern void client_recv( GuiWidget *widget, GuiEvent *event );
+extern void client_recv_packet( GuiWidget *widget, GuiEvent *event );
 extern int client_id;
 extern int client_topic_count;
 extern char *client_topics[];
 extern Text *client_help_text;
+extern NetSocket client;
+extern int client_is_connected;
+extern int client_state;
+extern int client_recv_limit;
+extern int (*sys_printf)(const char *format, ...);
 
 /*
 ====================================================================
@@ -71,7 +76,6 @@ GuiWidget *list_chatter;
 GuiWidget *edit_chatter;
 GuiWidget *list_levels;
 GuiWidget *list_users;
-GuiWidget *list_games;
 GuiWidget *list_channels;
 GuiWidget *edit_channel;
 GuiWidget *list_pausechatter;
@@ -79,9 +83,9 @@ GuiWidget *edit_pausechatter;
 GuiWidget *list_topic;
 GuiWidget *list_help;
 
-#define HINT_CONNECT "Use the numerical IP address of the game server. (xxx.xxx.xxx.xxx:xxxxx)#"\
-"DO NOT use 'localhost' if you run the server on your computer as you won't be able to "\
-"challenge others then. Use the IP queried by /sbin/ifconfig instead."
+#define HINT_CONNECT "Specify the game server as address:port where "\
+"the address can be a name or a dotted IP.#If the connection fails have a look "\
+"at the messages in the chat window to see the reason."
 
 /*
 ====================================================================
@@ -151,6 +155,31 @@ static int client_render_chatter(
     }
     return 1;
 }
+static int client_render_pause_chatter( 
+    int x, int y, SDL_Surface *buffer )
+{
+    char *ptr = 0, *name_end = 0;
+    StkFont *font = 0;
+    if ( y < 0 || y >= CHAT_LINE_COUNT ) return 0;
+    if ( pause_chatter[y][0] == '!' ) {
+        font = chat_font_error;
+        ptr = pause_chatter[y] + 1;
+    }
+    else {
+        ptr = pause_chatter[y];
+        font = chat_font_normal;
+    }
+    font->align = STK_FONT_ALIGN_LEFT;
+    stk_font_write( font, buffer, 2,0, STK_OPAQUE, ptr );
+    if ( pause_chatter[y][0] == '<' )
+    if ( ( name_end = strchr( pause_chatter[y], '>' ) ) ) {
+        name_end[1] = 0;
+        stk_font_write( 
+            chat_font_name, buffer, 2,0, STK_OPAQUE, pause_chatter[y] );
+        name_end[1] = ' ';
+    }
+    return 1;
+}
 /*
 ====================================================================
 Render levelsets.
@@ -188,54 +217,6 @@ static int client_render_user(
 }
 /*
 ====================================================================
-Render game
-====================================================================
-*/
-static int client_render_game( 
-    int x, int y, SDL_Surface *buffer )
-{
-    ClientGame *game;
-    char aux[8];
-    int name_x = 230;
-    int score_x = 410;
-    StkFont *font;
-    if ( y >= client_games->count ) return 0;
-    if ( ( game = list_get( client_games, y ) ) == 0 ) return 0;
-    /* levelset */
-    chat_font_normal->align = STK_FONT_ALIGN_LEFT;
-    stk_font_write( chat_font_normal, buffer, 
-        2,0, STK_OPAQUE, game->levelset );
-    /* : */
-    stk_font_write( chat_font_normal, buffer, 
-        name_x,0, STK_OPAQUE, ":" );
-    stk_font_write( chat_font_normal, buffer, 
-        score_x,0, STK_OPAQUE, ":" );
-    /* host */
-    if ( game->host_wins > game->guest_wins )
-        font = chat_font_name;
-    else
-        font = chat_font_normal;
-    font->align = STK_FONT_ALIGN_RIGHT;
-    stk_font_write( font, buffer, 
-        name_x,0, STK_OPAQUE, game->host );
-    sprintf( aux, "%i", game->host_wins );
-    stk_font_write( font, buffer, 
-        score_x,0, STK_OPAQUE, aux );
-    /* guest */
-    if ( game->host_wins < game->guest_wins )
-        font = chat_font_name;
-    else
-        font = chat_font_normal;
-    font->align = STK_FONT_ALIGN_LEFT;
-    stk_font_write( font, buffer, 
-        name_x+font->width,0, STK_OPAQUE, game->guest );
-    sprintf( aux, "%i", game->guest_wins );
-    stk_font_write( font, buffer, 
-        score_x+font->width,0, STK_OPAQUE, aux );
-    return 1;
-}
-/*
-====================================================================
 Render channel.
 ====================================================================
 */
@@ -246,7 +227,7 @@ static int client_render_channel(
     chat_font_normal->align = STK_FONT_ALIGN_LEFT;
     stk_font_write( chat_font_normal, 
         buffer, 2,0, STK_OPAQUE, 
-        ((ClientChannel*)list_get( client_channels, y ))->name );
+        (char*)list_get( client_channels, y ) );
     return 1;
 }
 #endif    
@@ -266,23 +247,13 @@ client_create() installs client_delete() as exit function.
 void client_create( void )
 {
 #ifdef NETWORK_ENABLED
-    char server[24];
-    char aux[8];
     GuiWidget *parent;
     SDL_Surface *surface;
-    /* initialize network functions */	
-    net_init();
-    /* initiate net messages */
-    net_init_msgs();
     /* users, channels, games */
     client_data_create();
     /* CONNECT WINDOW */
-    /* wallpaper with a box. */
-    dlg_connect = gui_box_create( 0, 0, 0, 640, 480, 0, 0 );
-    surface = gui_widget_get_surface( dlg_connect );
-    stk_surface_apply_wallpaper( 
-        surface, 0,0,-1,-1, bkgnds[0], STK_OPAQUE );
-    parent = gui_box_create( dlg_connect, -1,-1, 400, 214, 0, 0 );
+    dlg_connect = gui_box_create( 0, -1,-1, 400, 224, 0, 0 );
+    parent = dlg_connect;
     /* hint label */
     gui_label_create( 
         parent, 10, 10, parent->width - 20, 100, 1, 
@@ -291,24 +262,23 @@ void client_create( void )
     gui_label_create( 
         parent, 10, 120, 180, 20, 0, 
         0, 2, 0, STK_FONT_ALIGN_RIGHT, "Server:" );
-    snprintf( server, 24, "%s:%i", config.host, config.port );
     edit_server = gui_edit_create(
         parent, parent->width - 190, 120, 180, 20,
-        0, 2, 0, 22, server );
+        0, 2, 0, 22, config.server );
     /* user name */
     gui_label_create( 
         parent, 10, 150, 180, 20, 0, 
         0, 2, 0, STK_FONT_ALIGN_RIGHT, "Username:" );
     edit_username = gui_edit_create(
         parent, parent->width - 190, 150, 180, 20,
-        0, 2, 0, 13, "player" );
+        0, 2, 0, 13, config.username );
     /* cancel, connect buttons */
     gui_button_create(
         parent, parent->width/2 -160, 180, 
         140, 24, client_connect, 0,0,0,0,0, "Connect" );
     gui_button_create(
         parent, parent->width/2 +20, 180, 
-        140, 24, client_quit, 0,0,0,0,0, "Cancel" );
+        140, 24, client_close_connect_window, 0,0,0,0,0, "Cancel" );
     /* INFO */
     dlg_info = gui_box_create( 0, -1,-1, 300, 114, 0, 1 );
     label_info = gui_label_create( dlg_info, -1,10,276,60,0, 0,
@@ -331,28 +301,23 @@ void client_create( void )
         "Cancel" );
     /* CHATROOM */
     dlg_chatroom = gui_box_create( 0, 0,0,640,480, 
-        client_recv, 1 );
+        client_recv_packet, 1 );
     gui_widget_enable_event( dlg_chatroom, GUI_TIME_PASSED );
     surface = gui_widget_get_surface( dlg_chatroom );
     stk_surface_apply_wallpaper( 
         surface, 0,0,-1,-1, cr_wallpaper, STK_OPAQUE );
     /* chat window */
-    list_chatter = gui_list_create( dlg_chatroom, 0,0,470,300, NULL,
+    list_chatter = gui_list_create( dlg_chatroom, 0,0,470,444, NULL,
         0, 1, 14, 20, client_render_chatter, GUI_LIST_NO_SELECT );
     /* edit + send/whisper buttons */
-    gui_button_create( dlg_chatroom, 330,303,70,24, 
+    gui_button_create( dlg_chatroom, 330,448,70,24, 
         client_send_chatter, 0,0,0,0,0, "Send" );
-    gui_button_create( dlg_chatroom, 400,303,70,24, 
+    gui_button_create( dlg_chatroom, 400,448,70,24, 
         client_whisper_chatter, 0,0,0,0,0, "Whisper" );
-    edit_chatter = gui_edit_create( dlg_chatroom, 0,303,327,24,
-        client_send_chatter, 2, 0, CHAT_MSG_LIMIT, "" );
+    edit_chatter = gui_edit_create( dlg_chatroom, 0,448,327,24,
+        client_send_chatter, 2, 0, MAX_CHATTER_SIZE, "" );
     gui_widget_enable_event( edit_chatter, GUI_KEY_RELEASED );
     gui_widget_set_default_key_widget( dlg_chatroom, edit_chatter );
-    /* label + running games list */
-    gui_label_create( dlg_chatroom, 0,330,470,20,1,
-        NULL, 2, 0, STK_FONT_ALIGN_CENTER_X, "Matches" );
-    list_games = gui_list_create( dlg_chatroom, 0,353,470,120, NULL,
-        1, 1, 14, 20, client_render_game, GUI_LIST_NO_SELECT );
     /* channel button + users in channel */
     label_channel = gui_label_create( dlg_chatroom, 
         474,0,142,18,1, NULL,
@@ -365,21 +330,15 @@ void client_create( void )
         1, 1, 14, 20, client_render_user, 
         GUI_LIST_SINGLE_SELECT );
     /* levels label, levels, transfer button */
-    gui_label_create( dlg_chatroom, 474,164,124,18,1, NULL,
+    gui_label_create( dlg_chatroom, 474,164,160,18,1, NULL,
         2, 0, STK_FONT_ALIGN_CENTER_X, "Levelsets" );
-    gui_button_create( dlg_chatroom, 
-        598,164,18,18, client_listen,
-        0,0,0,0,0, "L" );
-    gui_button_create( dlg_chatroom, 
-        616,164,18,18, client_transfer,
-        0,0,0,0,0, "T" );
     list_levels = gui_list_create( dlg_chatroom, 
         474,184,160,120, client_handle_levelset_list,
         1, 1, 14, 20, client_render_levelset, 
         GUI_LIST_SINGLE_SELECT );
     /* box with level settings */
     parent = gui_box_create( dlg_chatroom,
-        474,306,160,116, NULL, 0 );
+        474,306,160,94, NULL, 0 );
     gui_label_create( parent, 2,2,102,20,0, NULL,
         2, NULL, STK_FONT_ALIGN_LEFT, "Difficulty:" );
     gui_spinbutton_create( parent, 102,2,50,20, 
@@ -400,20 +359,18 @@ void client_create( void )
     gui_spinbutton_create( parent, 102,2+66,50,20,
         client_update_balls,
         1, 6, 1, config.mp_balls );
-    gui_label_create( parent, 2,2+88,102,20,0, NULL,
-        2, NULL, STK_FONT_ALIGN_LEFT, "Game Port:" );
-    sprintf( aux, "%i", config.client_game_port );
-    gui_edit_create( parent, 102,2+88,50,20,
-        client_update_port,
-        2, 0, 6, aux );
     /* challenge & disconnect */
     gui_button_create( dlg_chatroom, 
-        474,424,160,20, client_challenge,
+        474,402,160,20, client_challenge,
         0,0,0,0,0, "Challenge" );
+    gui_button_create( dlg_chatroom,
+	474,dlg_chatroom->height-44,160,20,
+	client_open_connect_window,
+	0,0,0,0,0, "Connect" );
     gui_button_create( dlg_chatroom, 
         534,dlg_chatroom->height-20,100,20, 
-        client_disconnect,
-        0,0,0,0,0, "Disconnect" );
+        client_quit,
+        0,0,0,0,0, "Quit" );
     gui_button_create( dlg_chatroom, 
         474,dlg_chatroom->height-20,50,20, 
         client_popup_help,
@@ -429,7 +386,7 @@ void client_create( void )
         -1,180, 176,20, NULL,
         2, 0, 12, "" );
     gui_widget_set_default_key_widget( dlg_channels, edit_channel );
-    gui_edit_set_filter( edit_channel, GUI_EDIT_ALPHANUMERICAL );
+    gui_edit_set_filter( edit_channel, GUI_EDIT_ALPHANUMERICAL2 );
     gui_button_create( dlg_channels, 
         dlg_channels->width/2-90,210,80,20, 
         client_enter_channel, 0,0,0,0,0, "Enter" );
@@ -452,11 +409,11 @@ void client_create( void )
     dlg_pauseroom = gui_box_create( 0, -1,-1,480,366, NULL, 1 );
     list_pausechatter = gui_list_create( 
         dlg_pauseroom, 0,0,470,300, NULL,
-        0, 1, 14, 20, client_render_chatter, 
+        0, 1, 14, 20, client_render_pause_chatter, 
         GUI_LIST_NO_SELECT );
     edit_pausechatter = gui_edit_create( 
         dlg_pauseroom, 0,303,470,24,
-        client_send_pausechatter, 2, 0, CHAT_MSG_LIMIT, "" );
+        client_send_pausechatter, 2, 0, MAX_CHATTER_SIZE, "" );
     gui_widget_enable_event( edit_pausechatter, GUI_KEY_RELEASED );
     gui_widget_set_default_key_widget( dlg_pauseroom, edit_pausechatter );
     gui_button_create( dlg_pauseroom, -1,334,100,20,
@@ -485,8 +442,6 @@ void client_create( void )
     gui_list_goto( list_pausechatter, -1 );
     /* set help topics */
     gui_list_update( list_topic, client_topic_count );
-    /* update levels */
-    client_update_levelsets();
     /* call client_delete at exit */
     atexit( client_delete );
 #endif
@@ -511,12 +466,45 @@ Run the connect dialogue & chatroom until user closes the connect
 dialogue.
 ====================================================================
 */
+#ifdef NETWORK_ENABLED
+static int client_printf_info( const char *format, ... )
+{
+	va_list args;
+	char string[MAX_CHATTER_SIZE];
+	
+	va_start( args, format );
+	vsnprintf( string, MAX_CHATTER_SIZE, format, args );
+	va_end( args );
+	
+	client_add_chatter( string, 1 );
+	return strlen(string);
+}
+#endif
 void client_run( void )
 {
-    gui_enable_event_filter();
-    gui_widget_show( dlg_connect );
-    stk_display_fade( STK_FADE_IN, STK_FADE_DEFAULT_TIME );
-    gui_run( dlg_connect );
-    stk_display_fade( STK_FADE_OUT, STK_FADE_DEFAULT_TIME );
-    gui_disable_event_filter();
+#ifdef NETWORK_ENABLED
+	/* init UDP socket */
+	sys_printf = client_printf_info;
+	net_init( atoi(config.local_port) );
+	sys_printf = printf;
+	client_add_chatter( "Press 'Connect' to connect to a game server.", 1 );
+
+	client_state = CLIENT_NONE;
+	client_recv_limit = config.recv_limit;
+
+	gui_enable_event_filter();
+	gui_widget_show( dlg_chatroom );
+	stk_display_fade( STK_FADE_IN, STK_FADE_DEFAULT_TIME );
+	gui_run( dlg_chatroom );
+	stk_display_fade( STK_FADE_OUT, STK_FADE_DEFAULT_TIME );
+	gui_disable_event_filter();
+
+	if ( client_is_connected ) {
+		/* tell server we are off */
+		client_disconnect();
+		/* finalize UDP socket */
+		socket_print_stats( &client );
+	}
+	net_shutdown();
+#endif
 }
