@@ -16,24 +16,17 @@
  ***************************************************************************/
 
 #include "lbreakout.h"
-#include "chart.h"
-#include "config.h"
-#include "event.h"
-#include "levels.h"
-#include "player.h"
-#include "display.h"
-#include "paddle.h"
-#include "bricks.h"
-#include "extras.h"
-#include "frame.h"
+#include "../game/game.h"
 #include "game.h"
+#include "config.h"
+#include "bricks.h"
+#include "frame.h"
 #include "editor.h"
 
 SDL_Surface *sel_frame = 0, *buttons = 0;
 SDL_Surface *editor_bkgnd = 0; /* background (black with frame) of editor */
-enum  { EDITOR_LEVEL_LIMIT = 40 };
 char  edit_file_name[512]; /* full path of edited file */
-Level *edit_levels[EDITOR_LEVEL_LIMIT]; /* editor levels */
+Level *edit_levels[MAX_LEVELS]; /* editor levels */
 char edit_version[16]; /* version of edited set */
 int   edit_level_count; /* how many levels currently used? */
 int   edit_cur_level_id;
@@ -79,7 +72,6 @@ extern SDL_Surface *extra_pic;
 extern SDL_Surface *brick_pic;
 extern StkFont *mfont; /* use menu's font to draw status */
 extern StkFont *font; /* use game's font to confirm */
-extern int motion, motion_x, motion_y, motion_button;
 extern Config config;
 extern int stk_quit_request;
 
@@ -275,7 +267,7 @@ void editor_draw_status()
     mfont->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
     stk_font_write( mfont, stk_display, x, y, STK_OPAQUE, str );
     /* current level */
-    sprintf( str, "Current Level: %i/%i (Free: %i)", edit_cur_level_id + 1, edit_level_count, EDITOR_LEVEL_LIMIT - edit_level_count );
+    sprintf( str, "Current Level: %i/%i (Free: %i)", edit_cur_level_id + 1, edit_level_count, MAX_LEVELS - edit_level_count );
     mfont->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
     stk_font_write( mfont, stk_display, x, y + height, STK_OPAQUE, str );
     /* swap */
@@ -376,9 +368,9 @@ Free all editor levels
 void editor_clear_levels()
 {
     int i;
-    for ( i = 0; i < EDITOR_LEVEL_LIMIT; i++ )
+    for ( i = 0; i < MAX_LEVELS; i++ )
         if ( edit_levels[i] ) level_delete( edit_levels[i] );
-    memset( edit_levels, 0, sizeof( Level* ) * EDITOR_LEVEL_LIMIT );
+    memset( edit_levels, 0, sizeof( Level* ) * MAX_LEVELS );
     edit_level_count = 0;
 }
 /*
@@ -513,14 +505,14 @@ void editor_handle_button( int type, int *full_update ) {
             *full_update = 1;
             break;
         case BUTTON_ADD:
-            if ( edit_level_count == EDITOR_LEVEL_LIMIT ) break;
+            if ( edit_level_count == MAX_LEVELS ) break;
             if ( !confirm( font, "Add Level? y/n", CONFIRM_YES_NO ) ) break;
             edit_levels[edit_level_count] = level_create_empty( edit_levels[edit_level_count - 1]->author, edit_levels[edit_level_count - 1]->name );
             edit_level_count++;
             *full_update = 1;
             break;
         case BUTTON_INSERT:
-            if ( edit_level_count == EDITOR_LEVEL_LIMIT ) break;
+            if ( edit_level_count == MAX_LEVELS ) break;
             if ( !confirm( font, "Insert Level? y/n", CONFIRM_YES_NO ) ) break;
             for ( i = edit_level_count; i > edit_cur_level_id; i-- )
                 edit_levels[i] = edit_levels[i - 1];
@@ -547,7 +539,7 @@ void editor_handle_button( int type, int *full_update ) {
             /* translate */
             editor_translate_level( edit_cur_level, INDICES_2_CHAR );
             /* run */
-            game_test_level( edit_cur_level );
+            client_game_test_level( edit_cur_level );
             /* translate back */
             editor_translate_level( edit_cur_level, CHAR_2_INDICES );
             *full_update = 1;
@@ -647,14 +639,12 @@ void editor_handle_click( int x, int y, int set, int *full_update )
     strcpy( str, "" );
     if ( edit_buttons[x][y] == BUTTON_EDIT_AUTHOR )
         if ( enter_string( font, "Author's Name:", str, 24 ) ) {
-            free( edit_cur_level->author );
-            edit_cur_level->author = strdup( str );
+            snprintf( edit_cur_level->author, 31, str );
             *full_update = 1;
         }
     if ( edit_buttons[x][y] == BUTTON_EDIT_NAME )
         if ( enter_string( font, "Title:", str, 24 ) ) {
-            free( edit_cur_level->name );
-            edit_cur_level->name = strdup( str );
+            snprintf( edit_cur_level->name, 31, str );
             *full_update = 1;
         }
     /* sel frame tile position */
@@ -679,7 +669,7 @@ void editor_create()
 {
     int i, j;
     /* clear all level pointers */
-    memset( edit_levels, 0, sizeof( Level* ) * EDITOR_LEVEL_LIMIT );
+    memset( edit_levels, 0, sizeof( Level* ) * MAX_LEVELS );
     /* load sel frame */
     sel_frame = stk_surface_load( SDL_SWSURFACE, "sel_frame.png" );
     /* load buttons */
@@ -769,16 +759,21 @@ void editor_run()
     int leave = 0;
     int ms;
     int last_switch_time = 0;
-    int full_update = 0;
+    int full_update = 0, set;
+	int x, y, xoff,yoff;
+	Uint8 buttonstate;
+   
+	/* reset any alpha keys */
+	SDL_SetAlpha( extra_pic, 0,0 );
     /* draw first time */
     editor_full_update();
     /* main loop */
     stk_timer_reset();
-    while ( !leave ) {
-        if ( event_poll( &event ) ) {
+    while ( !leave && !stk_quit_request ) {
+        if ( SDL_PollEvent( &event ) ) {
             switch ( event.type ) {
                 case SDL_QUIT: leave = 1; stk_quit_request = 1; break;
-                case SDL_MOUSEBUTTONUP:
+                case SDL_MOUSEBUTTONDOWN:
                     editor_handle_click( event.button.x / BRICK_WIDTH,
                                          event.button.y / BRICK_HEIGHT,
                                          (event.button.button == STK_BUTTON_LEFT),
@@ -803,12 +798,12 @@ void editor_run()
                 default: break;
             }
         }
-        /* mouse motion is extra */
-        if ( motion && motion_button ) {
-            editor_handle_click( motion_x / BRICK_WIDTH,
-                                 motion_y / BRICK_HEIGHT,
-                                 (motion_button == STK_BUTTON_LEFT),
-                                 &full_update );
+        /* mouse motion is handled directly */
+	buttonstate = SDL_GetRelativeMouseState( &xoff, &yoff );
+	if ( (xoff || yoff) && buttonstate ) {
+		buttonstate = SDL_GetMouseState( &x, &y );
+		set = 0; if ( buttonstate & SDL_BUTTON(1) ) set = 1;
+		editor_handle_click( x / BRICK_WIDTH, y / BRICK_HEIGHT, set, &full_update );
         }
         ms = stk_timer_get_time();
         if ( ( last_switch_time -= ms ) <= 0 ) {
