@@ -78,6 +78,9 @@ int game_stats[2][7]; /* network game stats */
 int stats_received = 0;
 int game_over = 0; /* network game is over */
 int allow_disintegrate = 1; /* wether Plane of Inner Stability may be entered */
+char best_name[32];
+int  best_score; /* result of first place in chart of local set */
+int  showing_best = 0; /* if true best score is shown, thus display should not be updated */
 Display *display_score[2]; /* either score or frags */
 Display *display_player[2]; /* player name and lifes or wins */
 extern int client_state;
@@ -170,7 +173,10 @@ static int init_level( Player *player, int l_pos )
 		/* we put these displays to the old positions 
 		   at the top of the frame */
 		sprintf( str, "%s", player->name );
-		length = ( strlen( player->name ) ) * 8;
+		length = strlen(best_name);
+		if (strlen(player->name)>length )
+		  length = strlen(player->name);
+		length *= 8;
 		display_player[0] = displays_add( 402, 0,
 				length + 4, 16, str, player->lives, 0 );
 		display_score[0] = displays_add( stk_display->w - 52 - 76, 0,
@@ -462,6 +468,31 @@ void close_pause_chat( void )
 	gui_widget_enable_event( dlg_chatroom, GUI_TIME_PASSED );
 }
 
+/* Pause/unpause a local/network game. */
+static void client_set_pause( int pause )
+{
+  if (game_set==0) return; /* test level */
+  if (pause&&client_state==CS_PLAY)
+    {
+      /* in local game simply darken the screen, in
+       * network game enter the pausechatroom */
+      if ( game->game_type == GT_LOCAL ) {
+	set_state(CS_PAUSE);
+	display_text( font, "Pause" );
+      }
+      else {
+	open_pause_chat( "You have paused the game." );
+	comm_send_short( MSG_PAUSE );
+      }
+    }
+  else if (!pause&&client_state==CS_PAUSE)
+    {
+      /* unpause (local game only)*/
+      if ( game->game_type == GT_LOCAL )
+	set_state(CS_PLAY);
+    }
+}
+
 /* modify the client and its state according to the key pressed */
 static int handle_default_key( int key, int *abort )
 {
@@ -535,26 +566,10 @@ static int handle_default_key( int key, int *abort )
 		case SDLK_t:
 			return 0;
 		case SDLK_p:
-			if ( client_state != CS_PLAY && client_state != CS_PAUSE ) break;
-			if ( game_set == 0 ) break; /* test level */
-			if ( client_state == CS_PLAY ) {
-				/* pause */
-
-				/* in local game simply darken the screen, in
-				 * network game enter the pausechatroom */
-				if ( game->game_type == GT_LOCAL ) {
-					set_state(CS_PAUSE);
-					display_text( font, "Pause" );
-				}
-				else {
-					open_pause_chat( "You have paused the game." );
-					comm_send_short( MSG_PAUSE );
-				}
-			} else {
-				/* unpause (local game only)*/
-				if ( game->game_type == GT_LOCAL )
-					set_state(CS_PLAY);
-			}
+			if ( client_state == CS_PLAY )
+			  client_set_pause(1);
+			else if (client_state==CS_PAUSE)
+			  client_set_pause(0);
 			return 1;
 		default: 
 			if ( client_state != CS_PLAY ) break;
@@ -611,10 +626,11 @@ static void update_game( int ms )
 		comm_recv();
 		
 		/* update score displays */
-		display_set_value( 
-			display_score[0], 
-			game->paddles[0]->player->stats.total_score + 
-			game->paddles[0]->score );
+		if (!showing_best)
+		  display_set_value( 
+			  display_score[0], 
+			  game->paddles[0]->player->stats.total_score + 
+			  game->paddles[0]->score );
 		if ( game->game_type == GT_NETWORK )
 			display_set_value( 
 				display_score[1], 
@@ -760,6 +776,37 @@ void save_local_game( int slot_id )
     slot_update_hint( slot_id, item_resume_0->hint );
 }
 
+/* check whether Shift is pressed to switch between own and highest score */
+void handle_display_switch()
+{
+  int modstate = 0;
+  modstate = SDL_GetModState();
+  if (!showing_best)
+    {
+      if (modstate&KMOD_RSHIFT||modstate&KMOD_LSHIFT)
+	{
+	  display_set_text( display_player[0], best_name );
+	  display_set_value_directly( display_score[0], best_score );
+	  display_set_highlight( display_player[0], 1 );
+	  display_set_highlight( display_score[0], 1 );
+	  showing_best = 1;
+	}
+    }
+  else
+    {
+      if (!(modstate&KMOD_RSHIFT||modstate&KMOD_LSHIFT))
+	{
+	  display_set_text( display_player[0], cur_player->name );
+	  display_set_value_directly( display_score[0],
+			     game->paddles[0]->player->stats.total_score +
+			     game->paddles[0]->score );
+	  display_set_highlight( display_player[0], 0 );
+	  display_set_highlight( display_score[0], 0 );
+	  showing_best = 0;
+	}
+    }
+}
+
 /*
 ====================================================================
 Publics
@@ -796,6 +843,7 @@ void client_game_delete()
  * has to load the next level */
 int client_game_init_local( char *setname )
 {
+        Set_Chart *chart;
 	int i, warp_limit;
 
 	warp_limit = config.rel_warp_limit;
@@ -830,6 +878,15 @@ int client_game_init_local( char *setname )
 	else
 		game_set = levelset_load( setname );
 	if ( game_set == 0 ) return 0;
+
+	/* load highest score so far if any */
+	chart = chart_set_query(setname);
+	strcpy(best_name,"nobody"); best_score = 0;
+	if (chart)
+	  {
+	    strcpy(best_name,chart->entries[0].name);
+            best_score = chart->entries[0].score;
+	  }
 	
 	/* create client game context */
 	game = game_create( GT_LOCAL, config.diff, warp_limit );
@@ -943,6 +1000,7 @@ int client_game_init_testing( Level *level )
 	game_set_convex_paddle( config.convex );
 	game_set_ball_auto_return( !config.return_on_click );
 	game_set_ball_random_angle( config.random_angle );
+        game_set_ball_accelerated_speed( config.maxballspeed_float );
 	
 	game = game_create( GT_LOCAL, config.diff, 100 );
 	game_set_current( game );
@@ -1005,10 +1063,22 @@ void client_game_run( void )
 				if ( handle_default_key( key_pressed, &abort ) )
 					key_pressed = 0;
 			}
+			else
+			if (event.type == SDL_ACTIVEEVENT)
+		          {
+			    if (event.active.state == SDL_APPINPUTFOCUS ||
+				event.active.state == SDL_APPACTIVE )
+                            if (event.active.gain == 0 )
+			      client_set_pause(1);
+			  }
 		}
 		else if ( client_state == CS_PAUSE && game->game_type == GT_NETWORK )
 			gui_dispatch_event( 0, ms );
 
+		/* check whether Shift is pressed to switch between own and highest score */
+		if (game->game_type == GT_LOCAL)
+		  handle_display_switch();
+
 		/* let server know we're still alive except
 		 * in CS_PLAY as we send paddle updates there */
 		if ( game->game_type == GT_NETWORK )
