@@ -70,7 +70,8 @@ StkSound *wav_expand = 0, *wav_shrink = 0, *wav_frozen = 0;
 SDL_Surface *ball_pic = 0; /* ball pictures */
 SDL_Surface *ball_shadow = 0;
 #ifdef AUDIO_ENABLED
-StkSound *wav_reflect = 0;
+StkSound *wav_reflect_brick = 0;
+StkSound *wav_reflect_paddle = 0;
 StkSound *wav_attach = 0;
 #endif
 SDL_Surface *shot_pic = 0;
@@ -96,6 +97,7 @@ SDL_Surface *frame_mp_left = 0, *frame_mp_right = 0; /* multiplayer variants */
 SDL_Surface *frame_mp_left_shadow = 0, *frame_mp_right_shadow = 0;
 SDL_Surface *lamps = 0; /* life lamps */
 StkFont *display_font;
+StkFont *display_highlight_font;
 #ifdef AUDIO_ENABLED
 StkSound *wav_life_up = 0, *wav_life_down = 0;
 #endif
@@ -226,6 +228,8 @@ void theme_load_frame()
     lamps = theme_load_surf( "life.png" );
     display_font = theme_load_font_fixed( "f_frame.png", 32, 96, 8 );
     display_font->align = STK_FONT_ALIGN_RIGHT | STK_FONT_ALIGN_CENTER_Y;
+    display_highlight_font = theme_load_font_fixed( "f_small_white.png", 32, 96, 8 );
+    display_highlight_font->align = STK_FONT_ALIGN_RIGHT | STK_FONT_ALIGN_CENTER_Y;
 	
 	/* waves */
 #ifdef AUDIO_ENABLED
@@ -450,7 +454,8 @@ void theme_load( char *name )
     ball_shadow = create_shadow( ball_pic, 0, 0, ball_w, ball_h );
     /* ball sounds */
 #ifdef AUDIO_ENABLED
-    wav_reflect = theme_load_sound( "reflect.wav" );
+    wav_reflect_brick = theme_load_sound( "reflect_brick.wav" );
+    wav_reflect_paddle = theme_load_sound( "reflect_paddle.wav" );
     wav_attach = theme_load_sound( "attach.wav" );
 #endif
     /* shot gfx */
@@ -589,7 +594,8 @@ void theme_delete()
     stk_surface_free( &ball_pic );
     stk_surface_free( &ball_shadow );
 #ifdef AUDIO_ENABLED
-    stk_sound_free( &wav_reflect );
+    stk_sound_free( &wav_reflect_paddle );
+    stk_sound_free( &wav_reflect_brick );
     stk_sound_free( &wav_attach );
 #endif
     stk_surface_free( &shot_pic );
@@ -628,6 +634,7 @@ void theme_delete()
     stk_surface_free( &frame_top_shadow );
     stk_surface_free( &lamps );
     stk_font_free( &display_font );
+    stk_font_free( &display_highlight_font );
 #ifdef AUDIO_ENABLED
     stk_sound_free( &wav_life_up );
     stk_sound_free( &wav_life_down );
