@@ -36,7 +36,8 @@ int ball_w = 12;
 int ball_h = 12;
 extern Game *cur_game;
 
-int last_ball_reflect_x = -1; /* HACK: used to play local sound */
+int last_ball_brick_reflect_x = -1; /* HACK: used to play local sound */
+int last_ball_paddle_reflect_x = -1; /* HACK: used to play local sound */
 int last_ball_attach_x = -1; /* HACK: used to play local sound */
 
 /*
@@ -158,8 +159,8 @@ void ball_check_brick_reflection( Ball *b )
 	b->cur.y = b->target.y; b->y = (int)b->cur.y;
 
 	if ( reflect ) {
-		cur_game->mod.reflected_ball_count++;
-                last_ball_reflect_x = b->x; /* HACK: used to play local sound */
+		cur_game->mod.brick_reflected_ball_count++;
+                last_ball_brick_reflect_x = b->x; /* HACK: used to play local sound */
 		old_vx = b->vel.x;
 		if ( !chaos_reflect ) {
 			/* normal reflection */
@@ -208,11 +209,6 @@ void ball_handle_paddle_contact( Ball *ball, Paddle *paddle, Vector perp_vector
 	float  old_vx = ball->vel.x;
 	Vector c; /* A(perp_vector) = c; */
 
-	/* count successful paddle contacts */
-	paddle->balls_reflected++;
-	cur_game->mod.reflected_ball_count++;
-        last_ball_reflect_x = ball->x; /* HACK: used to play local sound */
-
 	ball->paddle = paddle;
 	
 	/* valid perpendicular? */
@@ -277,6 +273,11 @@ void ball_handle_paddle_contact( Ball *ball, Paddle *paddle, Vector perp_vector
 		return;
 	}
 
+	/* count successful paddle contacts */
+	paddle->balls_reflected++;
+	cur_game->mod.paddle_reflected_ball_count++;
+        last_ball_paddle_reflect_x = ball->x; /* HACK: used to play local sound */
+
 	/* get new target */
 	ball->get_target = 1;
 
@@ -832,60 +833,6 @@ void ball_corner_check( Ball *ball,
 	}
 }
 
-/*
-====================================================================
-Detach all balls to the passed direction (-1 or 1) and return True
-if there were any balls detached. As balls within walls are not
-fired the result may differ from paddle::attached_ball_count!
-====================================================================
-*/
-static int balls_detach_from_paddle( Paddle *paddle, int dir )
-{
-	Ball *ball;
-	int fired = 0;
-	
-	list_reset( cur_game->balls );
-	while ( ( ball = list_next( cur_game->balls ) ) ) {
-		if ( !ball->attached || ball->paddle != paddle )
-			continue;
-		/* balls in walls (hehe) are not fired */
-		if ( ball->x + paddle->x < BRICK_WIDTH )
-			continue;
-		if ( ball->x + ball_dia + paddle->x >= 640 - BRICK_WIDTH )
- 			continue;
-		/* release ball */
-		ball->attached = 0;
-		ball->paddle->attached_ball_count--;
-		ball->moving_back = ball->idle_time = ball->return_allowed = 0;
-		ball->x += paddle->x;
-		ball->y += paddle->y;
-		ball->cur.x = ball->x;
-		ball->cur.y = ball->y;
-		if ( !cur_game->balls_use_random_angle ) {
-			/* when random angle is used the vector is not
-			 * changed but the one before the attachment is
-			 * used */
-			ball->vel.x = (float)dir;
-			if ( ball->paddle->type == PADDLE_TOP )
-				ball->vel.y = 1.2;
-			else
-				ball->vel.y = -1.2;
-			/* only use 2 degree steps */
-			ball->angle = vec2angle( &ball->vel );
-			angle2vec( ball->angle, &ball->vel );
-			vector_set_length( &ball->vel, cur_game->ball_v );
-		}
-		ball->get_target = 1;
-		fired = 1;
-	}
-
-	/* if no balls are attached anymore set last contact time */
-	if ( fired && paddle->attached_ball_count == 0 )
-		paddle->last_ball_contact = SDL_GetTicks();
-	
-	return fired;
-}
-
 /*
 ====================================================================
 Public
@@ -1007,7 +954,7 @@ void balls_update( int ms )
         {
             if ( cur_game->paddles[0]->maxballspeed_request && !cur_game->paddles[0]->maxballspeed_request_old )
             {
-                cur_game->ball_v = cur_game->accelerated_ball_speed; 
+                cur_game->ball_v = cur_game->accelerated_ball_speed;
                 balls_set_velocity( cur_game->balls, cur_game->ball_v );
             }
             if ( !cur_game->paddles[0]->maxballspeed_request && cur_game->paddles[0]->maxballspeed_request_old )
@@ -1751,4 +1698,57 @@ void balls_set_velocity( List *balls, double vel )
     }
 }
 
+/*
+====================================================================
+Detach all balls to the passed direction (-1 or 1) and return True
+if there were any balls detached. As balls within walls are not
+fired the result may differ from paddle::attached_ball_count!
+====================================================================
+*/
+int balls_detach_from_paddle( Paddle *paddle, int dir )
+{
+	Ball *ball;
+	int fired = 0;
+	
+	list_reset( cur_game->balls );
+	while ( ( ball = list_next( cur_game->balls ) ) ) {
+		if ( !ball->attached || ball->paddle != paddle )
+			continue;
+		/* balls in walls (hehe) are not fired */
+		if ( ball->x + paddle->x < BRICK_WIDTH )
+			continue;
+		if ( ball->x + ball_dia + paddle->x >= 640 - BRICK_WIDTH )
+ 			continue;
+		/* release ball */
+		ball->attached = 0;
+		ball->paddle->attached_ball_count--;
+		ball->moving_back = ball->idle_time = ball->return_allowed = 0;
+		ball->x += paddle->x;
+		ball->y += paddle->y;
+		ball->cur.x = ball->x;
+		ball->cur.y = ball->y;
+		if ( !cur_game->balls_use_random_angle ) {
+			/* when random angle is used the vector is not
+			 * changed but the one before the attachment is
+			 * used */
+			ball->vel.x = (float)dir;
+			if ( ball->paddle->type == PADDLE_TOP )
+				ball->vel.y = 1.2;
+			else
+				ball->vel.y = -1.2;
+			/* only use 2 degree steps */
+			ball->angle = vec2angle( &ball->vel );
+			angle2vec( ball->angle, &ball->vel );
+			vector_set_length( &ball->vel, cur_game->ball_v );
+		}
+		ball->get_target = 1;
+		fired = 1;
+	}
+
+	/* if no balls are attached anymore set last contact time */
+	if ( fired && paddle->attached_ball_count == 0 )
+		paddle->last_ball_contact = SDL_GetTicks();
+	
+	return fired;
+}
 
