@@ -429,13 +429,24 @@ void bricks_add_mod( int x, int y, int mod, int dest_type, Vector imp, Paddle *p
 	if ( cur_game->mod.brick_hit_count > MAX_MODS ) return; /* drop hit */
 
 	hit = &cur_game->mod.brick_hits[cur_game->mod.brick_hit_count++];
+	memset(hit,0,sizeof(BrickHit)); /* clear hit */
 	
 	if ( mod == HT_REMOVE ) {
 		if ( paddle->extra_active[EX_GOLDSHOWER] )
 			if ( cur_game->bricks[x][y].extra == EX_NONE )
 				hit->gold_shower = 1;
-		if ( dest_type == SHR_BY_NORMAL_BALL && cur_game->extra_active[EX_EXPL_BALL] )
-			dest_type = SHR_BY_EXPL;
+		if (cur_game->bricks[x][y].type==MAP_BRICK_EXP)
+		      hit->draw_explosion = 1;
+		if (dest_type==SHR_BY_DELAYED_EXPL)
+		  {
+		    dest_type = SHR_BY_EXPL; /* delayed explosion thus initiated by a close-by
+						explosion have no explosion animation */
+		  }
+		else if (dest_type==SHR_BY_NORMAL_BALL && cur_game->extra_active[EX_EXPL_BALL])
+		  {
+		    dest_type = SHR_BY_EXPL;
+		    hit->draw_explosion = 1;
+		  }
 	}
 
 	hit->x = x; hit->y = y; 
@@ -467,10 +478,10 @@ void bricks_update( int ms )
 		while ( ( brick = list_next( cur_game->exp_bricks ) ) != 0 ) {
 			if ( (brick->exp_time -= ms) <= 0 ) {
 				brick->exp_time = -1;
-				brick_remove( brick->mx, brick->my, SHR_BY_EXPL, 
-						vector_get( 0, 0 ), brick->exp_paddle );
 				bricks_add_mod( brick->mx, brick->my, 
-						HT_REMOVE, SHR_BY_EXPL, 
+						HT_REMOVE, SHR_BY_DELAYED_EXPL, 
+						vector_get( 0, 0 ), brick->exp_paddle );
+				brick_remove( brick->mx, brick->my, SHR_BY_EXPL, 
 						vector_get( 0, 0 ), brick->exp_paddle );
 				balls_check_targets( brick->mx, brick->my );
 				list_delete_current( cur_game->exp_bricks );
