@@ -42,9 +42,13 @@ char *stk_audio_path = 0;
 SDL_Rect stk_srect, stk_drect;
 int stk_old_alpha = 0;
 int stk_audio_ok = 0;
-int stk_audio_mixchannel_count = 8;
+#ifdef AUDIO_ENABLED
+int stk_audio_mixchannel_count = MIX_CHANNELS;
+#else
+int stk_audio_mixchannel_count = 0;
+#endif
 int stk_audio_sound_enabled = 1;
-int stk_audio_sound_volume = 128;
+int stk_audio_sound_volume = 127;
 int stk_audio_buffer_size = 512;
 int stk_screenshot_id = 1;
 
@@ -660,9 +664,7 @@ SDL_Surface* stk_surface_load( int flags, char *format, ... )
     
     /* convert if display open */
     if ( stk_display ) {
-        converted_surface = 
-            SDL_ConvertSurface( surface, 
-                                stk_display->format, flags );
+        converted_surface = SDL_DisplayFormat( surface );
         if ( converted_surface == 0 ) {
             fprintf( stderr, "Conversion of %s failed: %s\n", 
                      path, SDL_GetError() );
@@ -1292,7 +1294,7 @@ void stk_audio_set_sound_volume( int volume )
 {
     if ( !stk_audio_ok ) return;
     if ( volume < 0 ) volume = 0;
-    if ( volume > 128 ) volume = 128;
+    if ( volume > 127 ) volume = 127;
     stk_audio_sound_volume = volume;
 #ifdef AUDIO_ENABLED
     Mix_Volume( -1, volume ); /* all sound channels */
@@ -1410,10 +1412,37 @@ Play a sound.
 */
 void stk_sound_play( StkSound *sound )
 {
+    int channel;
 #ifdef AUDIO_ENABLED
     if ( stk_audio_ok && stk_audio_sound_enabled ) {
-        Mix_Volume( sound->channel, sound->volume );
-        Mix_PlayChannel( sound->channel, sound->chunk, 0 );
+        /* if channel is -1 use first free channel */
+        channel = sound->channel;
+        if ( channel == -1 )
+            channel = Mix_GroupAvailable(-1);
+        Mix_Volume( channel, sound->volume );
+        Mix_PlayChannel( channel, sound->chunk, 0 );
+    }
+#endif
+}
+/*
+====================================================================
+Play a sound at horizontal position x..
+====================================================================
+*/
+void stk_sound_play_x( int x, StkSound *sound )
+{
+    int channel;
+#ifdef AUDIO_ENABLED
+    if ( stk_audio_ok && stk_audio_sound_enabled ) {
+        x = (x - 40) * 255 / (640 - 40 - 40);
+        if (x < 0) x = 0;
+        if (x > 255) x = 255;
+        /* if channel is -1 use first free channel */
+        channel = sound->channel;
+        if ( channel == -1 )
+            channel = Mix_GroupAvailable(-1);
+        Mix_SetPanning( channel, 255 - x, x );
+        Mix_PlayChannel( channel, sound->chunk, 0 );
     }
 #endif
 }
